Linear Algebra
==============

``bewegung`` offers a bunch of convenience classes for tasks related to linear algebra. They are neither very performant nor feature-complete.

.. toctree::
   :maxdepth: 2
   :caption: The API in detail

   vectors
   camera
